defunct: Defunct functions

defunctR Documentation

Defunct functions

Description

[Defunct]

These functions were deprecated for at least five release cycles before being made defunct. If there's a known replacement, calling the function will tell you about it.

Usage

# Deprecated in 0.3.* -------------------------------------

iRfcb documentation built on March 1, 2026, 5:06 p.m.