Skip to contents

This function adjusts the classifications in manual annotation files based on a class2use file. It loads a specified class2use file and applies the adjustments to all relevant files in the specified manual folder. Optionally, it can also perform compression on the output files. This is the R equivalent function of start_mc_adjust_classes_user_training from the ifcb-analysis repository (Sosik and Olson 2007).

Usage

ifcb_adjust_classes(class2use_file, manual_folder, do_compression = TRUE)

Arguments

class2use_file

A character string representing the full path to the class2use file (should be a .mat file).

manual_folder

A character string representing the path to the folder containing manual annotation files. The function will look for files starting with 'D' in this folder.

do_compression

A logical value indicating whether to apply compression to the output files. Defaults to TRUE.

Value

None

Details

The MAT files are read and written directly from R, producing output identical to the MATLAB ifcb-analysis format.

References

Sosik, H. M. and Olson, R. J. (2007), Automated taxonomic classification of phytoplankton sampled with imaging-in-flow cytometry. Limnol. Oceanogr: Methods 5, 204–216.

Examples

if (FALSE) { # \dontrun{
ifcb_adjust_classes("data/config/class2use.mat",
                    "data/manual/2014/")
} # }