List Available CNN Models from a Gradio Classification Server
Source:R/ifcb_classify_models.R
ifcb_classify_models.RdQueries the Gradio API to retrieve the names of all CNN models available
for IFCB image classification. These model names can be passed to the
model_name argument of ifcb_classify_images() and ifcb_classify_sample().
Arguments
- gradio_url
A character string specifying the base URL of the Gradio application. Default is
"https://ifcb.serve.scilifelab.se", an instance hosted on the SciLifeLab Serve platform. A free example Hugging Face Space is also available at"https://irfcb-classify.hf.space"(limited resources, intended for testing and demonstration). For large-scale or production classification, deploy your own instance of the classification app with your own model (source code: https://github.com/EuropeanIFCBGroup/ifcb-inference-app) and pass its URL here.
Examples
if (FALSE) { # \dontrun{
# List available models
models <- ifcb_classify_models()
print(models)
# Use a specific model for classification
result <- ifcb_classify_images("image.png", model_name = models[1])
} # }