View source: R/ifcb_create_empty_manual_file.R
| ifcb_create_empty_manual_file | R Documentation |
This function was deprecated as it has been replaced by the function: ifcb_create_manual_file().
Generates a MAT file for IFCB data with an empty manual classification structure using a specified number of ROIs, class names, and saves it to a specified output file. This function utilizes a Python script for creating the structure.
ifcb_create_empty_manual_file(
roi_length,
class2use,
output_file,
classlist = 1,
do_compression = TRUE,
unclassified_id = deprecated()
)
The MAT file is written directly from R, producing output identical to the
MATLAB ifcb-analysis format. No Python installation is required.
No return value. This function is called for its side effects.
The created MAT file is saved at the specified output_file location.
## Not run:
# Create a MAT file with 100 ROIs, using a vector of class names, and save it to "output.mat"
ifcb_create_empty_manual_file(roi_length = 100,
class2use = c("unclassified", "Aphanizomenon_spp"),
output_file = "output.mat")
# Create a MAT file with 50 unclassified ROIs (1) and 50 Aphanizomenon_spp (2) ROIs
ifcb_create_empty_manual_file(roi_length = 100,
class2use = c("unclassified", "Aphanizomenon_spp"),
output_file = "output.mat",
classlist = c(rep(1, 50), rep(2, 50)))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.