View source: R/ifcb_extract_annotated_images.R
| ifcb_extract_annotated_images | R Documentation |
This function extracts labeled images from IFCB (Imaging FlowCytobot) data,
annotated using the MATLAB code from the ifcb-analysis repository (Sosik and Olson 2007).
It reads manually classified data, maps class indices to class names, and extracts
the corresponding Region of Interest (ROI) images, saving them to the specified directory.
ifcb_extract_annotated_images(
manual_folder,
class2use_file,
roi_folders,
out_folder,
skip_class = NA,
verbose = TRUE,
manual_recursive = FALSE,
roi_recursive = TRUE,
overwrite = FALSE,
scale_bar_um = NULL,
scale_micron_factor = 1/3.4,
scale_bar_position = "bottomright",
scale_bar_color = "black",
old_adc = FALSE,
use_python = FALSE,
gamma = 1,
normalize = FALSE,
add_trailing_numbers = TRUE,
roi_folder = deprecated()
)
If use_python = TRUE, the function tries to read the .mat file using ifcb_read_mat(), which relies on SciPy.
This approach may be faster than the default approach using R.matlab::readMat(), especially for large .mat files.
To enable this functionality, ensure Python is properly configured with the required dependencies.
You can initialize the Python environment and install necessary packages using ifcb_py_install().
If use_python = FALSE or if SciPy is not available, the function falls back to using R.matlab::readMat().
None. The function saves the extracted PNG images to the specified output directory.
Sosik, H. M. and Olson, R. J. (2007), Automated taxonomic classification of phytoplankton sampled with imaging-in-flow cytometry. Limnol. Oceanogr: Methods 5, 204–216.
ifcb_extract_pngs ifcb_extract_classified_images https://github.com/hsosik/ifcb-analysis
## Not run:
ifcb_extract_annotated_images(
manual_folder = "path/to/manual_folder",
class2use_file = "path/to/class2use_file.mat",
roi_folders = "path/to/roi_folder",
out_folder = "path/to/out_folder",
skip_class = 1 # Skip "unclassified"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.