- feature_files
A path to a folder containing feature files or a character vector of file paths.
- mat_folder
(Optional) Path to the folder containing class or manual annotation files.
- custom_images
(Optional) A character vector of image filenames in the format DYYYYMMDDTHHMMSS_IFCBXXX_ZZZZZ.png,
where "XXX" represents the IFCB number and "ZZZZZ" represents the ROI number.
These filenames should match the roi_number assignment in the feature_files and can be
used as a substitute for MATLAB files.
- custom_classes
(Optional) A character vector of corresponding class labels for custom_images.
- class2use_file
A character string specifying the path to the file containing the class2use variable (default: NULL).
- micron_factor
Conversion factor for biovolume to cubic micrometers. Default is 1 / 3.4.
- diatom_class
A character vector specifying diatom class names in WoRMS. Default: "Bacillariophyceae".
- marine_only
Logical. If TRUE, restricts the WoRMS search to marine taxa only. Default: FALSE.
- threshold
Threshold for selecting classification information ("opt" for above-threshold classification, otherwise "all"). Default: "opt".
- multiblob
Logical. If TRUE, includes multiblob features. Default: FALSE.
- feature_recursive
Logical. If TRUE, searches recursively for feature files when feature_files is a folder. Default: TRUE.
- mat_recursive
Logical. If TRUE, searches recursively for MATLAB files in mat_folder. Default: TRUE.
- drop_zero_volume
Logical. If TRUE, rows where Biovolume equals zero (e.g., artifacts such as smudges on the flow cell) are removed. Default: FALSE.
- use_python
Logical. If TRUE, attempts to read .mat files using a Python-based method (SciPy). Default: FALSE.
- verbose
Logical. If TRUE, prints progress messages. Default: TRUE.