View source: R/ifcb_read_hdr_data.R
| ifcb_read_hdr_data | R Documentation |
This function reads all IFCB instrument settings information files (.hdr) from a specified directory.
ifcb_read_hdr_data(
hdr_files,
gps_only = FALSE,
verbose = TRUE,
hdr_folder = deprecated()
)
hdr_files |
A character string or character vector specifying the path(s) to |
gps_only |
A logical value indicating whether to include only GPS information (latitude and longitude). Default is FALSE. |
verbose |
A logical value indicating whether to print progress messages. Default is TRUE. |
hdr_folder |
Use |
A data frame with sample names, GPS latitude, GPS longitude, and timestamps. When gps_only = TRUE, only samples with GPS coordinates are included.
## Not run:
# Extract all HDR data
hdr_data <- ifcb_read_hdr_data("path/to/data")
print(hdr_data)
# Extract only GPS data
gps_data <- ifcb_read_hdr_data("path/to/data", gps_only = TRUE)
print(gps_data)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.