if (FALSE) {
# Set a random seed to reproduce the random sampling
set.seed(123)
# Create zip archives for each subdirectory with up to 50 random images
ifcb_zip_images_by_class(
image_folder = "path/to/images",
output_dir = "path/to/zips",
n_images = 50
)
}
Run the code above in your browser using DataLab